@@ -3,8 +3,8 @@ use strict;
 
 use Carp "croak";
 use CGI;
-use CGI::Wiki::Plugin::Diff;
-use CGI::Wiki::Plugin::Locator::Grid;
+use Wiki::Toolkit::Plugin::Diff;
+use Wiki::Toolkit::Plugin::Locator::Grid;
 use OpenGuides::CGI;
 use OpenGuides::Feed;
 use OpenGuides::Template;
@@ -14,7 +14,7 @@ use URI::Escape;
 
 use vars qw( $VERSION );
 
-$VERSION = '0.54';
+$VERSION = '0.55';
 
 =head1 NAME
 
@@ -50,18 +50,18 @@ sub new {
     my $geo_handler = $self->config->geo_handler;
     my $locator;
     if ( $geo_handler == 1 ) {
-        $locator = CGI::Wiki::Plugin::Locator::Grid->new(
+        $locator = Wiki::Toolkit::Plugin::Locator::Grid->new(
                                              x => "os_x",    y => "os_y" );
     } elsif ( $geo_handler == 2 ) {
-        $locator = CGI::Wiki::Plugin::Locator::Grid->new(
+        $locator = Wiki::Toolkit::Plugin::Locator::Grid->new(
                                              x => "osie_x",  y => "osie_y" );
     } else {
-        $locator = CGI::Wiki::Plugin::Locator::Grid->new(
+        $locator = Wiki::Toolkit::Plugin::Locator::Grid->new(
                                              x => "easting", y => "northing" );
     }
     $wiki->register_plugin( plugin => $locator );
     $self->{locator} = $locator;
-    my $differ = CGI::Wiki::Plugin::Diff->new;
+    my $differ = Wiki::Toolkit::Plugin::Diff->new;
     $wiki->register_plugin( plugin => $differ );
     $self->{differ} = $differ;
     return $self;
@@ -69,7 +69,7 @@ sub new {
 
 =item B<wiki>
 
-An accessor, returns the underlying L<CGI::Wiki> object.
+An accessor, returns the underlying L<Wiki::Toolkit> object.
 
 =cut
 
@@ -91,7 +91,7 @@ sub config {
 
 =item B<locator>
 
-An accessor, returns the underlying L<CGI::Wiki::Plugin::Locator::UK> object.
+An accessor, returns the underlying L<Wiki::Toolkit::Plugin::Locator::UK> object.
 
 =cut
 
@@ -102,7 +102,7 @@ sub locator {
 
 =item B<differ>
 
-An accessor, returns the underlying L<CGI::Wiki::Plugin::Diff> object.
+An accessor, returns the underlying L<Wiki::Toolkit::Plugin::Diff> object.
 
 =cut
 
@@ -156,6 +156,9 @@ sub display_node {
         $tt_vars{"rss_".lc($type)."_url"} =
                            $config->script_name . "?action=rc;format=rss;"
                            . lc($type) . "=" . lc(CGI->escape($2));
+        $tt_vars{"atom_".lc($type)."_url"} =
+                           $config->script_name . "?action=rc;format=atom;"
+                           . lc($type) . "=" . lc(CGI->escape($2));
     }
 
     my %current_data = $wiki->retrieve_node( $id );
@@ -642,13 +645,26 @@ sub list_all_versions {
   # Last ten non-minor edits to Hammersmith pages in RSS 1.0 format
   $guide->display_feed(
                          feed_type          => 'rss',
+                         feed_listing       => 'recent_changes',
                          items              => 10,
                          ignore_minor_edits => 1,
                          locale             => "Hammersmith",
                      );
 
+  # All edits bob has made to pub pages in the last week in Atom format
+  $guide->display_feed(
+                         feed_type    => 'atom',
+                         feed_listing => 'recent_changes',
+                         days         => 7,
+                         username     => "bob",
+                         category     => "Pubs",
+                     );
+
 C<feed_type> is a mandatory parameter. Supported values at present are 
-"rss".
+"rss" and "atom".
+
+C<feed_listing> is a mandatory parameter. Supported values at present 
+are "recent_changes". (More values are coming soon though!)
 
 As with other methods, the C<return_output> parameter can be used to
 return the output instead of printing it to STDOUT.
@@ -660,28 +676,41 @@ sub display_feed {
 
     my $feed_type = $args{feed_type};
     croak "No feed type given" unless $feed_type;
+
+    my $feed_listing = $args{feed_listing};
+    croak "No feed listing given" unless $feed_listing;
     
     my $return_output = $args{return_output} ? 1 : 0;
 
-    my $items = $args{items} || "";
-    my $days  = $args{days}  || "";
-    my $ignore_minor_edits = $args{ignore_minor_edits} ? 1 : 0;
-    my $username = $args{username} || "";
-    my $category = $args{category} || "";
-    my $locale   = $args{locale}   || "";
+    # Basic criteria, whatever the feed listing type is
     my %criteria = (
-                       items              => $items,
-                       days               => $days,
-                       ignore_minor_edits => $ignore_minor_edits,
-                       feed_type          => $feed_type,
+                       feed_type             => $feed_type,
+                       feed_listing          => $feed_listing,
+                       also_return_timestamp => 1,
                    );
-    my %filter;
-    $filter{username} = $username if $username;
-    $filter{category} = $category if $category;
-    $filter{locale}   = $locale   if $locale;
-    if ( scalar keys %filter ) {
-        $criteria{filter_on_metadata} = \%filter;
+
+    # Feed listing specific criteria
+    if($feed_listing eq "recent_changes") {
+        $criteria{items} = $args{items} || "";
+        $criteria{days}  = $args{days}  || "";
+        $criteria{ignore_minor_edits} = $args{ignore_minor_edits} ? 1 : 0;
+
+        my $username = $args{username} || "";
+        my $category = $args{category} || "";
+        my $locale   = $args{locale}   || "";
+
+        my %filter;
+        $filter{username} = $username if $username;
+        $filter{category} = $category if $category;
+        $filter{locale}   = $locale   if $locale;
+        if ( scalar keys %filter ) {
+            $criteria{filter_on_metadata} = \%filter;
+        }
     }
+    elsif($feed_listing eq "node_all_versions") {
+        $criteria{name} = $args{name};
+    }
+
 
     my $feed = OpenGuides::Feed->new(
                                         wiki       => $self->wiki,
@@ -693,13 +722,20 @@ sub display_feed {
     
     if ($feed_type eq 'rss') {
         $output = "Content-Type: application/rdf+xml\n";
-    } else {
+    }
+    elsif ($feed_type eq 'atom') {
+        $output = "Content-Type: application/atom+xml\n";
+    }
+    else {
         croak "Unknown feed type given: $feed_type";
     }
     
-    $output .= "Last-Modified: " . $feed->feed_timestamp( %criteria ) . "\n\n";
+    # Get the feed, and the timestamp, in one go
+    my ($feed_output, $feed_timestamp) = 
+        $feed->make_feed( %criteria );
 
-    $output .= $feed->make_feed( %criteria );
+    $output .= "Last-Modified: " . $feed_timestamp . "\n\n";
+    $output .= $feed_output;
 
     return $output if $return_output;
     print $output;
@@ -785,7 +821,6 @@ body        { margin: 0px; }
 h1          { margin-bottom: 0px; font-style: italic; }
 h2          { margin-top: 0px; }
 #logo       { text-align: center; }
-#logo a img { border: 1px solid #000; }
 #about      { margin: 0em 0em 1em 0em; border-top: 1px solid #ddd; border-bottom: 1px solid #ddd; }
 #meta       { font-size: small; text-align: center;}
 </style>
@@ -798,10 +833,10 @@ h2          { margin-top: 0px; }
 <div id="content">
 <div id="logo">
 <a href="http://openguides.org/"><img 
-src="http://openguides.org/img/logo.jpg" alt="OpenGuides.org"></a>
+src="http://openguides.org/img/logo.png" alt="OpenGuides"></a>
 <h1><a href="$script_name">$site_name</a></h1>
 <h2>is powered by <a href="http://openguides.org/">OpenGuides</a> -<br>
-the guides built by you.</h2>
+the guides made by you.</h2>
 <h3>version <a href="http://search.cpan.org/~dom/OpenGuides-$VERSION">$VERSION</a></h3>
 </div>
 <div id="about">
@@ -828,7 +863,7 @@ development site</a>.
 </p>
 <p>
 Copyright &copy;2003-2006, <a href="http://openguides.org/">The OpenGuides
-Project</a>. "OpenGuides", "[The] Open Guide To..." and "The guides built by
+Project</a>. "OpenGuides", "[The] Open Guide To..." and "The guides made by
 you" are trademarks of The OpenGuides Project. Any uses on this site are made 
 with permission.
 </p>
@@ -942,7 +977,7 @@ sub commit_node {
     }
     $metadata{host} = $ENV{REMOTE_ADDR};
 
-    # CGI::Wiki::Plugin::RSS::ModWiki wants "major_change" to be set.
+    # Wiki::Toolkit::Plugin::RSS::ModWiki wants "major_change" to be set.
     $metadata{major_change} = ( $metadata{edit_type} eq "Normal edit" )
                             ? 1
                             : 0;
@@ -1120,7 +1155,7 @@ L<http://dev.openguides.org/>
 
 =item * L<http://openguides.org/|The OpenGuides website>, with a list of all live OpenGuides installs.
 
-=item * L<CGI::Wiki>, the Wiki toolkit which does the heavy lifting for OpenGuides
+=item * L<Wiki::Toolkit>, the Wiki toolkit which does the heavy lifting for OpenGuides
 
 =back
 
